.. module:: bana.OpenMaya.MMatrix

.. _openmaya_mmatrix:

OpenMaya.MMatrix
================

.. autosummary::
   :nosignatures:

   ~MMatrix.__str__
   ~MMatrix.bnGet


----

.. automethod:: MMatrix.__str__

----

.. automethod:: MMatrix.bnGet
